@@ -8,7 +8,7 @@ use Audio::Nama::Globals qw(:singletons :trackrw);
 #  -  edit name (i.e. sax-v1) used as key in %by_name
 #
 
-use Modern::Perl;
+use Modern::Perl '2020';
 our $VERSION = 1.0;
 use Carp;
 no warnings qw(uninitialized);
@@ -246,7 +246,7 @@ sub edit_track 		{ $Audio::Nama::tn{$_[0]->edit_name} }             # in version
 # -------- Edit routines; Main Namespace ------
 {
 package Audio::Nama;
-use Modern::Perl; use Carp;
+use Modern::Perl '2020'; use Carp;
 no warnings 'uninitialized';
 
 our (
