@@ -1,5 +1,6 @@
 package Audio::Nama::Graph;
-use Modern::Perl;
+use Modern::Perl '2020';
+our $VERSION = 1.0;
 use Carp;
 use Graph;
 use Audio::Nama::Util qw(input_node output_node);
