@@ -1,5 +1,5 @@
 package Audio::Nama;
-use Modern::Perl;
+use Modern::Perl '2020';
 
 sub check_level {
 
@@ -7,9 +7,9 @@ sub check_level {
 
 	my $ev = add_effect( { track => $track, type => 'ev' } );
 
-	# disable Master so unused tracks are pruned
+	# disable Main so unused tracks are pruned
 	
-	$tn{Master}->set(rw => OFF); 
+	$tn{Main}->set(rw => OFF); 
 
 	# direct target track to null
 	
@@ -20,21 +20,21 @@ sub check_level {
 		or throw("check_level: generate_setup failed!"), return;
 	connect_transport();
 	
-	eval_iam('start'); # don't use heartbeat
+	ecasound_iam('start'); # don't use heartbeat
 	sleep 2; # time for engine to stabilize
-	while( eval_iam('engine-status') ne 'finished'){ 
+	while( ecasound_iam('engine-status') ne 'finished'){ 
 		print q(.); sleep 1; update_clock_display()}; 
 	print " Done\n";
 
-	my $cs = eval_iam('cop-status');
+	my $cs = ecasound_iam('cop-status');
 
 	my ($level_output) = $cs =~ /Status info:\s*?\n(.+)\z/s;
-	Audio::Nama::mandatory_pager($level_output);
+	pager($level_output);
 
 	# restore previous state
 	
 	remove_effect($ev);
-	$tn{Master}->set(rw => MON); 
+	$tn{Main}->set(rw => MON); 
 	Audio::Nama::request_setup();
 }
 
@@ -43,8 +43,8 @@ sub automix {
 	# get working track set
 	
 	my @tracks = grep{
-					$tn{$_}->rec_status eq PLAY or
-					$bn{$_} and $tn{$_}->rec_status eq REC
+					$tn{$_}->play or
+					$bn{$_} and $tn{$_}->rec
 				 } $bn{Main}->tracks;
 
 	pager("tracks: @tracks");
@@ -56,19 +56,19 @@ sub automix {
 
 	#use Smart::Comments '###';
 	# add -ev to summed signal
-	my $ev = add_effect( { chain => $tn{Master}->n, type => 'ev' } );
+	my $ev = add_effect( { chain => $tn{Main}->n, type => 'ev' } );
 	### ev id: $ev
 
 	# turn off audio output
 	
-	my $old_send_type = $tn{Master}->{send_type};
-	my $old_send_id   = $tn{Master}->{send_id};
+	my $old_send_type = $tn{Main}->{send_type};
+	my $old_send_id   = $tn{Main}->{send_id};
 
-	$tn{Master}->set(send_type => 'null', send_id => 'null');
+	$tn{Main}->set(send_type => 'null', send_id => 'null');
 
 	### Status before mixdown:
 
-	process_command('show');
+	nama_cmd('show');
 
 	
 	### reduce track volume levels  to 10%
@@ -82,9 +82,9 @@ sub automix {
 
 	### reduce vol command: $reduce_vol_command
 
-	for (@tracks){ process_command("$_  $reduce_vol_command") }
+	for (@tracks){ nama_cmd("$_  $reduce_vol_command") }
 
-	process_command('show');
+	nama_cmd('show');
 
 	generate_setup('automix') # pass a bit of magic
 		or throw("automix: generate_setup failed!"), return;
@@ -92,14 +92,14 @@ sub automix {
 	
 	# start_transport() does a rec_cleanup() on transport stop
 	
-	eval_iam('start'); # don't use heartbeat
+	ecasound_iam('start'); # don't use heartbeat
 	sleep 2; # time for engine to stabilize
-	while( eval_iam('engine-status') ne 'finished'){ 
+	while( ecasound_iam('engine-status') ne 'finished'){ 
 		print q(.); sleep 1; update_clock_display()}; 
 	print " Done\n";
 
 	# parse cop status
-	my $cs = eval_iam('cop-status');
+	my $cs = ecasound_iam('cop-status');
 	### cs: $cs
 	my $cs_re = qr/Chain "1".+?result-max-multiplier ([\.\d]+)/s;
 	my ($multiplier) = $cs =~ /$cs_re/;
@@ -113,21 +113,21 @@ sub automix {
 	if ( $multiplier < 0.00001 ){
 
 		throw("Signal appears to be silence. Skipping.");
-		for (@tracks){ process_command("$_  $restore_vol_command") }
-		$tn{Master}->set(rw => MON);
+		for (@tracks){ nama_cmd("$_  $restore_vol_command") }
+		$tn{Main}->set(rw => MON);
 		return;
 	}
 
 	### apply multiplier to individual tracks
 
-	for (@tracks){ process_command( "$_ vol*$multiplier" ) }
+	for (@tracks){ nama_cmd( "$_ vol*$multiplier" ) }
 
 	### mixdown
-	process_command('mixdown; arm; start');
+	nama_cmd('mixdown; arm; start');
 
 	### restore audio output
 
-	$tn{Master}->set( send_type => $old_send_type, send_id => $old_send_id); 
+	$tn{Main}->set( send_type => $old_send_type, send_id => $old_send_id); 
 
 	#no Smart::Comments;
 	
