@@ -39,107 +39,6 @@ sub initialize_terminal {
 	$SIG{USR1} = sub { project_snapshot() };
 }
 
-sub setup_hotkeys {
-	say "\nHotkeys on!";
-	destroy_readline(); 
-	setup_termkey(); 
-	1
-}
-sub list_hotkeys { 
-	my $hots 		= dclone($config->{hotkeys});
-	my %hots = %$hots;
-	$hots{'='} 		= 'Enter numeric value';
-	$hots{ 'mN' } 	= 'Change step size to 10 raised to the Nth power';
-	$hots{ '#' }	= 'Engage hotkey mode (must be typed in column 1)';
-	pager("Hotkeys\n",Dumper \%hots)
-}
-
-
-sub setup_termkey {
-	$project->{events}->{termkey} = AnyEvent::TermKey->new(
-		term => \*STDIN,
-
-		on_key => sub {
-			my $key = shift;
-			my $key_string = $key->termkey->format_key( $key, FORMAT_VIM );
-			logpkg(__FILE__,__LINE__,'debug',"got key: $key_string");
-			# remove angle brackets around multi-character
-			# sequences, e.g. <PageUp> -> PageUp
-			$key_string =~ s/[<>]//g if length $key_string > 1;
-
-			exit_hotkey_mode(), cleanup_exit() if $key->type_is_unicode 
-						and $key->utf8 eq "C" 
-						and $key->modifiers & KEYMOD_CTRL;
-			 
-			# execute callback if we have one keystroke 
-			# and it has an "instant" mapping
-			 
-			my $suppress_status;
-			$key_string =~ s/ /Space/; # to suit our mapping file
-			if ( my $command = $config->{hotkeys}->{$key_string} 
-				and ! length $text->{hotkey_buffer}) {
-
-
-				$suppress_status++ if $key_string eq 'Escape'
-									or $key_string eq 'Space';
-
-
-				try { eval "$command()" }
-				catch { throw( qq(cannot execute subroutine "$command" for key "$key_string": $_") ) }
-			}
-
-			# otherwise assemble keystrokes and check
-			# them against the grammar
-			 
-			else {
-			$key_string =~ s/Space/ /; # back to the character
-			$text->{hotkey_buffer} .= $key_string;
-			print $key_string if length $key_string == 1;
-#			push $text->{hotkey_object_buffer}, $key;
-			$text->{hotkey_parser}->command($text->{hotkey_buffer})
- 				and reset_hotkey_buffers();
- 			}
-			print(
-				"\x1b[$text->{screen_lines};0H", # go to screen bottom line, column 0
-				"\x1b[2K",  # erase line
-				hotkey_status_bar(), 
-			) if $text->{hotkey_buffer} eq undef and ! $suppress_status;
-		},
-	);
-}
-sub hotkey_status_bar {
-	my $name = "[".$this_track->name."]"; 
-	return "$name has no selected effect" unless $this_track->op;
-	join " ", $name,
-				"Stepsize: ",$this_track->stepsize,
-				fxn($this_track->op)->fxname,
-				parameter_info($this_track->op, $this_track->param - 1);
-				
-;
-}
-sub reset_hotkey_buffers {
-	$text->{hotkey_buffer} = "";
-	$text->{hotkey_object_buffer} = [];
-}
-sub exit_hotkey_mode {
-	teardown_hotkeys();
-	initialize_terminal(); 
-	initialize_prompt();
-};
-sub teardown_hotkeys {
-	$project->{events}->{termkey}->termkey->stop(),
-		delete $project->{events}->{termkey} if $project->{events}->{termkey}
-}
-sub destroy_readline {
-	$text->{term}->rl_deprep_terminal() if $text->{term};
-	delete $text->{term}; 
-	delete $project->{events}->{stdin};
-}
-sub setup_hotkey_grammar {
-	$text->{hotkey_grammar} = get_data_section('hotkey_grammar');
-	$text->{hotkey_parser} = Parse::RecDescent->new($text->{hotkey_grammar})
-		or croak "Bad grammar!\n";
-}
 sub end_of_list_sound { system( $config->{hotkey_beep} ) }
 
 sub previous_track {
@@ -188,8 +87,7 @@ sub revise_prompt {
 	
 sub prompt { 
 	logsub((caller(0))[3]);
-	join ' ', 'nama', git_branch_display(), 
-						bus_track_display() ," ('h' for help)> "
+	join ' ', 'nama', git_branch_display(), bus_track_display(),'> '
 }
 sub detect_spacebar {
 
@@ -216,9 +114,6 @@ sub detect_spacebar {
 
 			
 		}
-		elsif (  $text->{term_attribs}->{line_buffer} eq "#" ){
-			setup_hotkeys();
-		}
 	});
 }
 sub throw {
